@@ -289,7 +289,7 @@ class Stockfish(Engine):
             Optional properties for Stockfish
         """
         if exe is None:
-            exe = '../Engines/Stockfish/Stockfish-sf_14.1/src/stockfish'
+            exe = 'Engines/Stockfish/Stockfish-sf_14.1/src/stockfish'
         super().__init__(exe, fen, props)
 
 
@@ -313,5 +313,5 @@ class Leela(Engine):
             Optionals properties for lc0
         """
         if exe is None:
-            exe = '../Engines/Leela/lc0-master/build/release/lc0'
+            exe = 'Engines/Leela/lc0-master/build/release/lc0'
         super().__init__(exe, fen, props)
